@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from decorated.base.function import Function, PartialFunction, Method
+from decorated.base.function import Function, partial
 from decorated.decorators.conditional import Conditional
 from decorated.decorators.events import Event
 from decorated.decorators.instantiate import Instantiate
@@ -9,8 +9,7 @@ from decorated.decorators.retries import Retries
 from decorated.decorators.synchronized import Synchronized
 
 Function = Function
-PartialFunction = PartialFunction
-Method = Method
+partial = partial
 
 Event = Event
 conditional = Conditional
